mafw.processor\_library.plotter
===============================

.. automodule:: mafw.processor_library.plotter

   
   .. rubric:: Classes

   .. autosummary::
   
      CatPlot
      DataRetriever
      DisPlot
      FigurePlotter
      FromDatasetDataRetriever
      GenericPlotter
      HDFDataRetriever
      PlotterMeta
      RelPlot
      SQLDataRetriever
   